@@ -8,16 +8,23 @@ from .callback import Callback
 from torchelper.models.base_model import BaseModel
 from torchelper.utils.dist_util import master_only, get_bare_model
 from torchelper.utils import logger
+from torchelper.models.trainable import Trainable
 
 class CkptCallback(Callback):
-    def __init__(self, ckpt_dir, name, restore_epoch=-1,
+    def __init__(self,
+                 model:BaseModel,
+                 ckpt_dir:str,
+                 name:str,
+                 restore_epoch=-1,
                  max_ckpts=10,
                  save_per_secs=2*60*60,
                  strict=False,
                  save_before_train=True,
                  best_metric_name=None):
+
         super().__init__()
         self.name = name
+        self.model = model
         self.best_metric_name = best_metric_name
         self.strict = strict
         self.ckpt_dir = ckpt_dir
@@ -149,7 +156,7 @@ class CkptCallback(Callback):
                 weight_name = '%s_weights_%s.pth'%(self.epochs[0], self.name)
                 opt_path = os.path.join(self.ckpt_dir, opt_name)
                 weight_path = os.path.join(self.ckpt_dir, weight_name)
-                print(opt_path)
+                logger.debug(opt_path)
                 if os.path.exists(opt_path):
                     os.remove(opt_path)
                 if os.path.exists(weight_path):
@@ -157,26 +164,26 @@ class CkptCallback(Callback):
                 del self.epochs[0]
 
 
-    def on_begin_train(self, model:BaseModel, epoch:int):
-        self.load_weights(model, self.restore_epoch)
+    def on_begin_train(self, epoch:int):
+        self.load_weights(self.model, self.restore_epoch)
         
         if self.save_before_train and epoch==0:
-            self.save_model(model, -1)
+            self.save_model(self.model, -1)
         
-    def on_end_val(self, model:BaseModel, epoch:int, metric_dict:dict):
-        self.__save_if_best(model, epoch, metric_dict)
+    def on_end_val(self, epoch:int, metric_dict:dict):
+        self.__save_if_best(self.model, epoch, metric_dict)
 
-    def on_end_train(self, model:BaseModel):
+    def on_end_train(self):
         pass
 
-    def on_begin_epoch(self, model:BaseModel, epoch:int):
+    def on_begin_epoch(self, epoch:int):
         pass
 
-    def on_end_epoch(self, model:BaseModel, epoch:int):
-        self.save_model(model, epoch)
+    def on_end_epoch(self, epoch:int):
+        self.save_model(self.model, epoch)
 
-    def on_begin_step(self, model:BaseModel, epoch:int, step:int):
+    def on_begin_step(self, epoch:int, step:int):
         pass
 
-    def on_end_step(self, model:BaseModel, epoch:int, step:int):
+    def on_end_step(self, epoch:int, step:int):
         pass
\ No newline at end of file
